# Integrations

## Test runners/build tools

The Launchable CLI includes pre-built integrations with the following test runners/build tools:

* [Ant](https://ant.apache.org/)
* [Bazel](https://bazel.build/)
* [Behave](https://pypi.org/project/behave/)
* [CTest](https://cmake.org/cmake/help/latest/manual/ctest.1.html#id13)
* [Cypress](https://www.cypress.io/)
* [GoogleTest](https://github.com/google/googletest)
* [Go Test](https://golang.org/pkg/testing/)
* [Gradle](https://gradle.org/)
* [Maven](https://maven.apache.org/)
* [RSpec](https://rspec.info/)
* [Minitest](https://github.com/seattlerb/minitest)
* [Nose](https://nose.readthedocs.io/en/latest/index.html)
* [Robot](https://robotframework.org/)

And if you aren't using any of those, the CLI also provides a [generic "file-based" integration](file.md).

{% hint style="info" %}
Using a tool not listed here? [Let us know.](mailto:support@launchableinc.com)
{% endhint %}

